@@ -39,15 +39,35 @@
 --
 -- In addition to the native format, Hakyll also supports hamlet templates. For
 -- more information on hamlet templates, please refer to:
--- <http://hackage.haskell.org/package/hamlet>.
+-- <http://hackage.haskell.org/package/hamlet>. Internally, hamlet templates are
+-- converted to hakyll templates -- which means that you can only use variable
+-- insertion (and not all hamlet's features).
+--
+-- This is an example of a valid hamlet template. You should place them in
+-- files with a @.hamlet@ extension:
+--
+-- > !!!
+-- > <html>
+-- >     <head>
+-- >         <meta charset="UTF-8">
+-- >         <title> MyAweSomeCompany - #{title}
+-- >     <body>
+-- >         <h1> MyAweSomeCompany - #{title}
+-- >         <div id="navigation">
+-- >             <a href="/index.html"> Home
+-- >             <a href="/about.html"> About
+-- >             <a href="/code.html"> Code
+-- >         #{body}
 --
 module Hakyll.Web.Template
     ( Template
     , applyTemplate
+    , applyTemplateWith
     , applySelf
     , templateCompiler
     , templateCompilerWith
     , applyTemplateCompiler
+    , applyTemplateCompilerWith
     ) where
 
 import Control.Arrow
@@ -65,17 +85,29 @@ import Hakyll.Web.Template.Read
 import Hakyll.Web.Page.Internal
 
 -- | Substitutes @$identifiers@ in the given @Template@ by values from the given
--- "Page". When a key is not found, it is left as it is. You can specify
--- the characters used to replace escaped dollars (@$$@) here.
+-- "Page". When a key is not found, it is left as it is.
 --
 applyTemplate :: Template -> Page String -> Page String
-applyTemplate template page =
+applyTemplate = applyTemplateWith defaultMissingHandler
+
+-- | Default solution if a key is missing: render it again
+defaultMissingHandler :: String -> String
+defaultMissingHandler k = "$" ++ k ++ "$"
+
+-- | A version of 'applyTemplate' which allows you to give a fallback option,
+-- which can produce the value for a key if it is missing.
+--
+applyTemplateWith :: (String -> String)  -- ^ Fallback if key missing
+                  -> Template            -- ^ Template to apply
+                  -> Page String         -- ^ Input page
+                  -> Page String         -- ^ Resulting page
+applyTemplateWith missing template page =
     fmap (const $ substitute =<< unTemplate template) page
   where
     map' = toMap page
     substitute (Chunk chunk) = chunk
-    substitute (Key key) = fromMaybe ("$" ++ key ++ "$") $ M.lookup key map'
-    substitute (Escaped) = "$"
+    substitute (Key key)     = fromMaybe (missing key) $ M.lookup key map'
+    substitute (Escaped)     = "$"
 
 -- | Apply a page as it's own template. This is often very useful to fill in
 -- certain keys like @$root@ and @$url@.
@@ -106,4 +138,13 @@ templateCompilerWith settings =
 
 applyTemplateCompiler :: Identifier Template                   -- ^ Template
                       -> Compiler (Page String) (Page String)  -- ^ Compiler
-applyTemplateCompiler identifier = require identifier (flip applyTemplate)
+applyTemplateCompiler = applyTemplateCompilerWith defaultMissingHandler
+
+-- | A version of 'applyTemplateCompiler' which allows you to pass a function
+-- which is called for a key when it is missing.
+--
+applyTemplateCompilerWith :: (String -> String)
+                          -> Identifier Template
+                          -> Compiler (Page String) (Page String)
+applyTemplateCompilerWith missing identifier =
+    require identifier (flip $ applyTemplateWith missing)
